<template>
    <div class="operating-assets">
        <PublicTitle :iconUrl="require('@/assets/img/publicTitle/icon-经营.png')" title="经营性资产" routerPath="/platLayout/assetsOperating"/>
        <div class="top-statistics">
            <div class="item">
                <div class="label-unit">建筑面积(㎡)</div>
                <div class="value">{{ floorArea.structureArea ? floorArea.structureArea : 0 }}</div>
                <div class="pending-value">
                    未确权面积<span class="red-span">{{ floorArea.unconfirmArea ? floorArea.unconfirmArea : 0 }}</span>
                </div>
            </div>
            <div class="item">
                <div class="label-unit">物业资产(㎡)</div>
                <div class="value">{{ propertyAssets.structureArea ? propertyAssets.structureArea : 0 }}</div>
                <div class="pending-value">
                    未确权面积<span>{{ propertyAssets.unconfirmArea ? propertyAssets.unconfirmArea : 0 }}</span>
                </div>
            </div>
            <div class="item">
                <div class="label-unit">商品房(㎡)</div>
                <div class="value">{{ productRoom.structureArea ? productRoom.structureArea : 0 }}</div>
                <div class="pending-value">
                    未确权面积<span>{{ productRoom.unconfirmArea ? productRoom.unconfirmArea : 0 }}</span>
                </div>
            </div>
        </div>
        <div class="bottom-chart">
            <div id="oriented-chart"></div>
        </div>
    </div>
</template>

<script>
import * as echarts from 'echarts'
import utils from '@/utils.js'
import api from '@/api/homePage.js'
import PublicTitle from '@/components/PublicTitle/index'
export default {
    name: 'OperatingAssets', // 经营性资产
    components: { PublicTitle },
    data() {
        return {
            echartsData: [],
            floorArea: {},//建筑面积
            propertyAssets: {},//物业资产
            productRoom: {},//商品房
        }
    },
    created() {
        this.getBusiness()
    },
    mounted() {
    },
    methods: {
        getBusiness() {
            api.businessStatistics({}, res => {
                if (res.state) {
                    res.value.areaInfo && res.value.areaInfo.forEach(e => {
                        if (e.name) {
                            this.floorArea = e
                        } else if (e.assetType === '0') {
                            this.propertyAssets = e
                        } else if (e.assetType === '1') {
                            this.productRoom = e
                        }
                    })
                    this.echartsData = res.value.bookValueInfo
                    this.initChat()
                }
            })
        },
        //字典翻译
        getDictName(code, value) {
            return utils.getDictName(code, value)
        },
        initChat() {
            console.log(this.echartsData);
            let nameData = []
            let bookValueData = []
            let areaData = []
            this.echartsData.forEach(e => {
                nameData.push(this.getDictName('zczt', e.assetStatus))
                bookValueData.push(e.bookValue)
                areaData.push(e.structure_area_)
            })
            let chartDom = echarts.init(
                document.getElementById('oriented-chart')
            )
            let option = {
                tooltip: {
                    trigger: 'axis',
                    axisPointer: {
                        // 坐标轴指示器，坐标轴触发有效
                        type: 'shadow', // 默认为直线，可选为：'line' | 'shadow'
                    },
                },
                legend: {
                    data: ['账面净值', '面积'],
                    align: 'left',
                    padding: [20, 0, 0, 0],
                },
                grid: {
                    left: '1%',
                    right: '1%',
                    bottom: '3%',
                    containLabel: true,
                },
                xAxis: [
                    {
                        type: 'category',
                        data: nameData,
                        axisTick: {
                            show: false,
                        },
                        axisLine: {
                            show: true,
                            lineStyle: {
                                color: '#A1A9B2', // 浅灰色
                            },
                        },
                        axisLabel: {
                            // fontSize: this.getSize() //设置坐标轴文本标签的字体大小
                        },
                    },
                ],
                yAxis: [
                    {
                        type: 'value',
                        name: '单位：万元',
                        axisLabel: {
                            formatter: '{value}',
                        },
                        splitLine: {
                            show: false,
                        },
                        axisLine: {
                            show: true,
                            lineStyle: {
                                color: '#A1A9B2', // 浅灰色
                            },
                        },
                    },
                    {
                        type: 'value',
                        name: '单位：㎡',
                        axisLabel: {
                            formatter: '{value}',
                        },
                        position: 'right',
                        splitLine: {
                            show: false,
                        },
                        axisLine: {
                            show: true,
                            lineStyle: {
                                color: '#A1A9B2', // 浅灰色
                            },
                        },
                    },
                ],
                series: [
                    {
                        name: '账面净值',
                        type: 'bar',
                        data: bookValueData,
                        barWidth: '15',
                        yAxisIndex: 0,
                        itemStyle: {
                            color: {
                                type: 'linear',
                                x: 0,
                                y: 0,
                                x2: 0,
                                y2: 1,
                                colorStops: [
                                    {
                                        offset: 0,
                                        color: '#55EDB0', // 渐变起始颜色（绿色）
                                    },
                                    {
                                        offset: 1,
                                        color: 'rgba(85,237,176,0.2)', // 渐变结束颜色（深绿色）
                                    },
                                ],
                            },
                            borderRadius: [3, 3, 0, 0], // 设置圆角大小
                        },
                    },
                    {
                        name: '面积',
                        type: 'bar',
                        data: areaData,
                        barWidth: '15',
                        yAxisIndex: 1,
                        itemStyle: {
                            color: {
                                type: 'linear',
                                x: 0,
                                y: 0,
                                x2: 0,
                                y2: 1,
                                colorStops: [
                                    {
                                        offset: 0,
                                        color: '#8AC4FF', // 渐变起始颜色（绿色）
                                    },
                                    {
                                        offset: 1,
                                        color: 'rgba(51,153,255,0.2)', // 渐变结束颜色（深绿色）
                                    },
                                ],
                            },
                            borderRadius: [3, 3, 0, 0], // 设置圆角大小
                        },
                    },
                ],
            }
            chartDom.setOption(option)
            window.addEventListener('resize', () => {
                chartDom.resize()
            })
        },
    },
}
</script>

<style scoped lang="scss">
.operating-assets {
    width: 100%;
    height: 100%;
    padding: 16px;
    box-sizing: border-box;
    background: #ffffff;
    box-shadow: 4px 4px 10px 0px rgba(53, 152, 220, 0.1);
    border-radius: 16px 16px 16px 16px;

    .top-statistics {
        display: flex;
        justify-content: space-between;
        margin-top: 5px;

        .item {
            box-sizing: border-box;
            width: 32%;
            height: 119px;
            padding: 16px 8px;
            background: linear-gradient(180deg,
                    #e5f1ff 0%,
                    rgba(255, 255, 255, 0) 100%);
            border-radius: 8px 8px 8px 8px;
            border: 1px solid;
            border-image: linear-gradient(180deg,
                    rgba(255, 255, 255, 0),
                    rgba(229.49999392032623, 240.73427349328995, 255, 1)) 1 1;

            .label-unit {
                font-size: 16px;
                color: #7a8899;
            }

            .value {
                margin-top: 8px;
                height: 34px;
                font-size: 26px;
                font-weight: 700;
                color: #0f2a4d;
                border-bottom: 1px solid #e2eaf3;
            }

            .pending-value {
                font-size: 14px;
                color: #7a8899;
                margin-top: 11px;

                span {
                    font-size: 14px;
                    color: #0f2a4d;
                }

                .red-span {
                    color: #e54552;
                }
            }
        }
    }

    .bottom-chart {
        width: 100%;
        height: calc(100% - 149px);

        #oriented-chart {
            width: 100%;
            height: 100%;
        }
    }
}
</style>
